@@ -233,7 +233,7 @@ use log::{debug, error, warn};
 extern crate lazy_static;
 
 pub const SERVER_ID: &str = "yedb-altt-rs";
-pub const VERSION: &str = "0.1.1";
+pub const VERSION: &str = "0.1.2";
 pub const ENGINE_VERSION: u8 = 1;
 
 pub const DEFAULT_CACHE_SIZE: usize = 1000;
@@ -317,14 +317,13 @@ impl<'a> DataKey<'a> {
 
 macro_rules! get_engine {
     ($e:expr) => {
-        match $e.engine {
-            Some(x) => x,
-            None => {
-                return Err(Error::new(
-                    ErrorKind::NotOpened,
-                    "The database is not opened",
-                ))
-            }
+        if let Some(engine) = $e.engine {
+            engine
+        } else {
+            return Err(Error::new(
+                ErrorKind::NotOpened,
+                "The database is not opened",
+            ));
         }
     };
 }
@@ -1514,10 +1513,10 @@ impl Database {
         if self.auto_bak > 0 && !key.starts_with(".schema/") && key != ".schema" {
             for n in 1..=self.auto_bak {
                 let key_name = format!("{}.bak{}", key, n);
-                match self._delete_key(&key_name, false, false, false) {
-                    Ok(_) => {}
-                    Err(e) if e.kind() == ErrorKind::KeyNotFound => {}
-                    Err(e) => return Err(e),
+                if let Err(e) = self._delete_key(&key_name, false, false, false) {
+                    if e.kind() != ErrorKind::KeyNotFound {
+                        return Err(e);
+                    }
                 }
             }
         }
@@ -1587,10 +1586,7 @@ impl Database {
     ///
     /// Will return Err if the key is not found and on I/O errors
     pub fn key_get(&mut self, key: &str) -> Result<Value, Error> {
-        return match self.get_key_data(DataKey::Name(key), false) {
-            Ok(v) => Ok(v.0),
-            Err(e) => Err(e),
-        };
+        Ok(self.get_key_data(DataKey::Name(key), false)?.0)
     }
 
     /// # Errors
